parameter property
The parameter the message is sent to. If this is null the message is sent to the return stream of the method.
Implementation
final String? parameter;
The parameter the message is sent to. If this is null the message is sent to the return stream of the method.
final String? parameter;