OpenMethodStreamResponseType enum

The response to an OpenMethodStreamCommand.

Inheritance
Available extensions

Values

success → const OpenMethodStreamResponseType

The stream was successfully opened.

endpointNotFound → const OpenMethodStreamResponseType

The endpoint was not found.

authenticationFailed → const OpenMethodStreamResponseType

The user is not authenticated.

authorizationDeclined → const OpenMethodStreamResponseType

The user is not authorized.

invalidArguments → const OpenMethodStreamResponseType

The arguments were invalid.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryParse(String name) OpenMethodStreamResponseType
Try to parse a OpenMethodStreamResponseType from a string. Throws an exception if the string is not recognized.

Constants

values → const List<OpenMethodStreamResponseType>
A constant List of the values in this enum, in order of their declaration.